
<?php

/*
   ------------------------------------------------------------------------
   Attach the source code generated by the Multi- Language VSOP87 Source
   Code Generator Tool for computing the heliocentric rectangular XYZ co-
   ordinates of Venus and Earth.
*/
   Include_Once('VSOP87C-Venus-hXYZ.php');
   Include_Once('VSOP87C-Earth-hXYZ.php');

/*
   ========================================================================
   These functions return the VSOP87C raw heliocentric rectangular X,Y,Z
   coordinates and distances of the planets Venus and Earth at the moment
   indicated by the Julian Date (JDTT) time variable.
   ========================================================================
*/
   function Venus_C_hXYZR($JDTT)
{
// ---------------------------------------------------------------
// Compute time variable in Julian centuries reckoned from J2000.0

   $t = (trim($JDTT) - 2451545) / 365250;

// -----------------------------------------------------------------
// Evaluate the heliocentric rectangular XYZ coordinate summations
// corresponding to the moment indicated by the time variable (t).

   $X = Venus_C_X0($t) + Venus_C_X1($t) + Venus_C_X2($t)
       + Venus_C_X3($t) + Venus_C_X4($t) + Venus_C_X5($t);

   $Y = Venus_C_Y0($t) + Venus_C_Y1($t) + Venus_C_Y2($t)
       + Venus_C_Y3($t) + Venus_C_Y4($t) + Venus_C_Y5($t);

   $Z = Venus_C_Z0($t) + Venus_C_Z1($t) + Venus_C_Z2($t)
       + Venus_C_Z3($t) + Venus_C_Z4($t) + Venus_C_Z5($t);

// ----------------------------------------------
// Compute heliocentric radius vector (distance).

   $R = SqRt($X*$X + $Y*$Y + $Z*$Z);

// Format the returned values to 14 decimals.
   $X = trim(SPrintF("%+18.14f",$X));
   $Y = trim(SPrintF("%+18.14f",$Y));
   $Z = trim(SPrintF("%+18.14f",$Z));
   $R = trim(SPrintF("%18.14f",$R));

// --------------------------------------------
// Return the heliocentric XYZR coordinates as
// a string consisting of four space-delimited
// numerical strings.

   return "$X $Y $Z $R";
}

// *******************************
// *******************************

   function Earth_C_hXYZR($JDTT)
{
// ---------------------------------------------------------------
// Compute time variable in Julian centuries reckoned from J2000.0

   $t = (trim($JDTT) - 2451545) / 365250;

// Evaluate the heliocentric rectangular XYZ coordinate summations
// corresponding to the moment indicated by the time variable (t).

   $X = Earth_C_X0($t) + Earth_C_X1($t) + Earth_C_X2($t)
       + Earth_C_X3($t) + Earth_C_X4($t) + Earth_C_X5($t);

   $Y = Earth_C_Y0($t) + Earth_C_Y1($t) + Earth_C_Y2($t)
       + Earth_C_Y3($t) + Earth_C_Y4($t) + Earth_C_Y5($t);

   $Z = Earth_C_Z0($t) + Earth_C_Z1($t) + Earth_C_Z2($t)
       + Earth_C_Z3($t) + Earth_C_Z4($t) + Earth_C_Z5($t);

// ----------------------------------------------
// Compute heliocentric radius vector (distance).

   $R = SqRt($X*$X + $Y*$Y + $Z*$Z);

// Format the returned values to 14 decimals.
   $X = trim(SPrintF("%+18.14f",$X));
   $Y = trim(SPrintF("%+18.14f",$Y));
   $Z = trim(SPrintF("%+18.14f",$Z));
   $R = trim(SPrintF("%18.14f",$R));

// --------------------------------------------
// Return the heliocentric XYZR coordinates as
// a string consisting of four space-delimited
// numerical values.

   return "$X $Y $Z $R";
}


?>


