<?php

/*
   VSOP87C Venus-Earth Heliocentric Rectangular XYZ Coordinates Tester
   and Geocentric Equatorial Ephemeris and Distance and Ecliptical
   Coordinates Statistics Computations.

   Author  : Jay Tanner
   License : Public Domain

*/

   ob_start();

// Attach essential modules.
   Include_Once('VSOP87C-Venus-hXYZ.php');
   Include_Once('VSOP87C-Earth-hXYZ.php');
   Include_Once('VSOP87C-Venus-hXYZR.php');
   Include_Once('VSOP87C-Geocentric-Venus.php');
   Include_Once('Utilities.php');

// Get current year (UTC).
   $cYear = GMDate('Y');

// Define the program cookie name and set it to expire in 30 days.
// This cookie can be shared by other programs in the same common
// home folder together.

   $CookieName = 'VSOP87C_Venus_Apparent_Geocentric_Equatorial_Ephemeris_Stats';
   $SetToExpireIn30Days = time() + 30*86400;

// --------------------------------
// Define script path and filename.

   $_AUTHOR_          = 'Jay Tanner';
   $_PROGRAM_VERSION_ = ''; $at = "&#97;&#116;"; $UTC = "&#85;&#84;&#67;";
   $_SCRIPT_PATH_     = Filter_Input(INPUT_SERVER, 'SCRIPT_FILENAME');
   $_RUN_             = Filter_Input(INPUT_POST, 'SCRIPT_NAME');

// -----------------------------------------------------------
// Define internal document page title, HTML page heading text
// and revision date

   $_INTERNAL_TITLE_  = "VSOP87 Venus Ephemeris Demo";
   $_INTERFACE_TITLE_ = "<span style='font-size:150%;'>VSOP87C Apparent Geocentric Equatorial Venus Ephemeris Demo</span><br><span style='font-size:100%;'>PHP Program by Jay Tanner - $cYear</span>";
   $_REVISION_DATE_   = $_PROGRAM_VERSION_ .'Revised: '. GMDate("l, F d, Y $at h:i:s A   $UTC", FileMTime($_SCRIPT_PATH_));

// Define dynamic source code download link.
   $DLLink = '';
   if (substr(Filter_Input(INPUT_SERVER, 'SCRIPT_FILENAME'), 0,3) <> 'D:/')
  {
   $DLLink = "<a href='vsop87-venus-ephemeris-demo.zip'>Download PHP Source Code For This Program</a>";
   $DLLink = "<tr><td colspan='3' style='background:black;'><b>$DLLink</b></td></tr>";
  }
// --------------------------------------
// Define main TextArea text, background
// colors and HTML table row span.

   $TxColor = 'black';
   $BgColor = 'white';
   $ColSpan = 7;

// ---------------------------------------------
// Do this only if [COMPUTE] button was clicked.

   $w = Filter_Input(INPUT_POST, 'ComputeButton');
   if (!IsSet($w))

// ----------------------------------------------------
// If [COMPUTE] button was clicked and an active cookie
// exists, then restore the previous interface settings
// from it.
     {
      $w = Filter_Input(INPUT_COOKIE, $CookieName);
   if (IsSet($w))
      {
       $CookieDataString = Filter_Input(INPUT_COOKIE, $CookieName);
       list($yn,$mn,$dn,$TT) = Preg_Split("[\|]", $CookieDataString);
      }

   else

// -------------------------------------------------
// Set the initial default interface startup values.

 {
// Define defaults.
   $yn = GMDate('Y');
   $mn = GMDate('n');
   $dn = GMDate('j');

   $TT = GMDate('H:i:s');

// -----------------------------------
// Store interface settings in cookie.

   $CookieDataString = "$yn|$mn|$dn|$TT";
   setcookie ($CookieName, $CookieDataString, $SetToExpireIn30Days);
  }
      } // End of  if (!isset(_POST['ComputeButton']))







// --------------------------------------
// Read values of all interface arguments
// and set defaults on initial call.

   $w = Filter_Input(INPUT_POST, 'ComputeButton');
   if (isset($w))
{
   $yn = trim(Filter_Input(INPUT_POST, 'yn'));
   $mn = trim(Filter_Input(INPUT_POST, 'mn'));
   $dn = trim(Filter_Input(INPUT_POST, 'dn'));

   $TT = trim(Filter_Input(INPUT_POST, 'TT'));

// ---------------------------------
// Define defaults for empty values.

   if ($yn == '') {$yn = GMDate('Y');}
   if ($mn == '') {$mn = GMDate('n');}
   if ($dn == '') {$dn = GMDate('j');}

   if ($TT == '') {$TT = GMDate('H:i:s');}



// ------------------------------------
// Store interface arguments in cookie.

   $CookieDataString = "$yn|$mn|$dn|$TT";
   SetCookie ($CookieName, $CookieDataString, $SetToExpireIn30Days);
}





// --------------------------------------------------
// Initialize error detection flag and error message.

   $ErrorFlag = FALSE; // Default = No error yet.
   $ErrorMssg = '';    // Default = Empty string.

// ------------------------------------------------
// CODE TO CHECK FOR INVALID ARGUMENTS CAN GO HERE.
// If error detected, set $ErrorFlag = TRUE and
// define error message text.




// -------------------------------------
// Check if error detected above (TRUE).

if ($ErrorFlag === TRUE)
 {
  $TxColor = 'white';
  $BgColor = '#CC0000';
  $TextArea2Text = '';

  $TextArea1Text =
"=== ERROR ====================================================================

$ErrorMssg";
 }

else

// ===================--================================
// Begin computations below if no errors detected above.

  {
// -----------------------------------------
// Format the interface values for neatness.

   $n = $mn;    $mn = SPrintF("%02d", $mn);
   $j = $dn;    $dn = SPrintF("%02d", $dn);

   $TT = Hours_to_HMS(HMS_to_Hours(Num_to_HMS($TT)), 0, '',':');

// ------------------------------------------------
// Compute the Julian Day Number for the given date
// according to the default Gregorian calendar.

   $JDNum = GregorianToJD(IntVal($mn), IntVal($dn), IntVal($yn));
   $JGCal = 'Gregorian';

// -----------------------------------------------------------
// Check if (JDNum < 2299161) and, if so, compute the Julian
// Day Number for the old-style Julian calendar instead. All
// JD Numbers for dates prior to 1582-Oct-15-Fri are < 2299161
// and reckoned according to the old-style Julian calendar.

   if ($JDNum < 2299161)
      {
       $JDNum = JulianToJD($mn, $dn, $yn);
       $JGCal = 'Julian';
      }
       $JG = substr($JGCal,0,1);

// --------------------------------------------
// Compute full Julian Date value for the given
// date and time (TT) elements and calendar mode.

   $JDTT = SPrintF("%16.8f", $JDNum - 0.5 + HMS_to_Hours($TT)/24);

// ----------------------------------------------------------
// Compute Delta T estimate from NASA polynomial expressions.

   $DeltaTSec = NASA_Delta_T_Poly($JDTT);
   $DeltaTHrs = NASA_Delta_T_Poly($JDTT)/3600;
   $DeltaTHMS = Hours_to_HMS($DeltaTHrs, 0, '+', ':');

// ----------------------------------------------------------
// Construct full calendar date and time string.

   $DateTimeTT = Inverse_JD($JDTT, $JG);

// --------------------------------------------------------
// Call the generated functions to compute the heliocentric
// rectangular XYZ coordinates to check if the functions are
// returning the correct values.

   $VenusHelioXYZR = Venus_C_hXYZR($JDTT);
   $EarthHelioXYZR = Earth_C_hXYZR($JDTT);

// -------------------------------------------------------------
// Compute final apparent geocentric Venus ephemeris statistics.

   $GeocentricVenusStats = Geocentric_Venus($JDTT);

// ---------------------------------------------------------------
// Extract returned apparent geocentric coordinates and store into
// their correaponding variables.

   list
  (
   $RAHrs,
   $DeclDeg,
   $DistAU,
   $AngDiamDeg,
   $VisMag,
   $PhAngDeg,
   $IllumFrac,
   $EclLonDeg,
   $EclLatDeg
  ) = Preg_Split("[ ]", $GeocentricVenusStats);

// ------------------------------------------
// Compute distances in millions of kilometers
// and miles.  1 AU = 149597870.691 km was the
// original value used in the VSOP87 theory.
   $DistKm = $DistAU * 149597870.691 / 1E6;
   $DistMi = $DistKm / 1.609344;

// ---------------------------------------
// Do some formatting for output neatness.

   $RAHMS        = Hours_to_HMS($RAHrs,   2, ''  ,'h');
   $DeclDMS      = trim(Deg_to_DMS($DeclDeg, 2, '+' ,'d'));
   $DistAU       = SPrintF("%1.10f", $DistAU);
   $DistKm       = SPrintF("%14.10f", $DistKm);
   $DistMi       = SPrintF("%14.10f", $DistMi);
   $AngDiamDMS   = Deg_to_DMS(trim($AngDiamDeg), 3, '' ,'d');
   $AngDiamDMS   = substr($AngDiamDMS, 9, StrLen($AngDiamDMS));
   $AngDiamDMS   = Str_Replace("00' ",'', $AngDiamDMS);
   $PhAngDeg     = SPrintF("%1.3f", $PhAngDeg);
   $IllumFracPct = SPrintF("%1.3f", 100*$IllumFrac);
   $VisMag       = SPrintF("%+1.2f", $VisMag);
   $EclLonDMS    = trim(Deg_to_DMS(trim($EclLonDeg), 2, ''  ,'d'));
   $EclLatDMS    = trim(Deg_to_DMS(trim($EclLatDeg), 2, '+' ,'d'));


// Construct output geocentric Venus ephemeris text block.
   $ApparentVenusCoords =
"For $JGCal Calendar Date and Time:
$DateTimeTT TT


Right Ascension  = $RAHrs h
                 = $RAHMS

Declination      = $DeclDeg&deg;
                 = $DeclDMS

Distance         = $DistAU AU
                 = $DistKm Mkm
                 = $DistMi Mmi

Angular Diameter = $AngDiamDeg&deg;
                 = $AngDiamDMS

Visual Magnitude = $VisMag

Phase Angle      = $PhAngDeg&deg;
Illuminated Disc = $IllumFracPct%

Ecliptical Lon.  = $EclLonDeg&deg;
                 = $EclLonDMS

Ecliptical Lat.  = $EclLatDeg&deg;
                 = $EclLatDMS
";



// ------------------------------
// Construct output text block 1.

   $TextArea1Text =
"
===========================================================================
               VSOP87C APPARENT GEOCENTRIC VENUS EPHEMERIS DEMO
                 Valid For 8000 Years From 2000 BC to 6000 AD

  Dates before 1582-Oct-15 are reckoned according to the Julian Calendar.
===========================================================================


For $JGCal Calendar Date and Time:
$DateTimeTT TT

Julian Date Value = $JDTT TT
Julian Day Number = $JDNum

Delta T = $DeltaTSec sec = $DeltaTHMS
This estimate is computed from the NASA Polynomial Expressions for Delta T,
for reference, but not actually applied to the ephemeris computations.

---------------------------------------------------------------------------
Venus VSOP87 Series C Raw Heliocentric Rectangular X,Y,Z Coordinates and
Distance R

'$VenusHelioXYZR'


---------------------------------------------------------------------------
Earth VSOP87 Series C Raw Heliocentric Rectangular X,Y,Z Coordinates and
Distance R

'$EarthHelioXYZR'



---------------------------------------------------------------------------
APPARENT VENUS GEOCENTRIC EQUATORIAL EPHEMERIS
STATISTICS AND ECLIPITICAL COORDINATES

$ApparentVenusCoords
";
  }



// TextArea2.
   $TextArea2Text =
"
SOME GENERAL INFORMATION ABOUT THIS VSOP87 VENUS EPHEMERIS DEMO

The purpose of this program is SIMPLY to test the VSOP87C functions to
see if they are returning the correct X,Y,Z values and if so, proceed
to compute the full apparent geocentric equatorial Venus ephemeris
statistics and ecliptical coordinates for the planet Venus at any
moment within the 8000-year ephemeris span from 2000 BC to 6000 AD.

-------
CAVEAT:
Be cautious when entering the date and time values. This program is only
a simplified demo and does NOT do extensive error checking for invalid
arguments.  Valid input arguments should return valid results.  Whenever
possible, compare against known check values or against another source
of similar VSOP87C computations for consistency.

----------------
TIME SCALE USED:
The program uses the system clock for the time (UTC). However, the actual
time scale used is the TT scale.  Without any Delta T adjustment, UTC is
being treated as equivalent to TT.

---------------------------------------------------------------------------
SOURCE CODE:
There is a link below to the complete PHP source code for this program.
";






// Determine the number of text rows to use in the output TextAreas.
   $TextArea1Rows = 2 + substr_count($TextArea1Text, "\n");
   $TextArea2Rows = 2 + substr_count($TextArea2Text, "\n");



print <<< _HTML

<!DOCTYPE HTML>

<head>

<meta name="viewport" content="width=device-width, initial-scale=1">
<meta http-equiv="content-type" content="text/html; charset=UTF-8">
<meta name="description" content="VSOP87 Venus Apparent Geocentric Equatorial Ephemeris Demo">
<meta name="keywords" content="VSOP87,VSOP87 Venus,VSOP87 Earth,VSOP87 Demo">
<meta name="author" content="Jay Tanner - https://www.PHPScienceLabs.com">
<meta http-equiv="pragma"  content="no-cache">
<meta http-equiv="expires" content="-1">
<meta name="robots"    content="index,follow">
<meta name="googlebot" content="index,follow">


<style>
 BODY
{color:silver; background-color:black;  font-family:Verdana; font-size:100%}

 TABLE
{font-size:12px; border: 1px solid black;}

 TD
{color:black; background-color:white; line-height:200%; font-size:12px;
padding:6px; text-align:center;}

 DIV
{
 color:black; background-color:white; font-family:Verdana; font-size:110%;
 text-align:justify; padding:4px;
}

 PRE
{color:black; background-color:white; font-family:monospace;
 font-size:150%; font-weight:bold; text-align:left; padding:4px;}

 CODE
{font-family:monospace; font-size:150%; font-weight:normal;}

 TEXTAREA
{
 color:black; background:white; font-family:monospace; font-size:150%;
 font-weight:bold; border-radius: 8px; border:1px solid black; padding:4px;
 white-space:pre;
}

 INPUT[type="text"]::-ms-clear {width:0; height:0;}

 INPUT[type="text"]
{
 color:black; background:white; font-size:150%; font-family:monospace;
 font-weight:bold; text-align:center; box-shadow:2px 2px 3px #666666;
 border:2px solid black; border-radius:4px;
}

 INPUT[type="text"]:focus
{
 background:white; box-shadow:2px 2px 3px #666666; font-family:monospace;
 font-size:150%; border:2px solid blue; text-align:center;
 font-weight:bold; border-radius:4px;
}

 INPUT[type="submit"]
{font-weight:bold;}

 INPUT[type="submit"]:hover
{box-shadow:2px 2px 5px #555555; font-weight:bold;}

 HR {background:black; height:2px; border:0px;}

 A:link
{
 font-size:100%; background:transparent; color:DodgerBlue; font-family:Verdana;
 font-weight:bold; text-decoration:none; line-height:175%; padding:3px;
 border:1px solid transparent;
}

 A:visited {font-size:100%; background:transparent; color:DodgerBlue;}

 A:hover
{
 font-size:100%; background:yellow; color:black; border:1px solid black;
 box-shadow:1px 1px 3px #222222;
}

 A:active  {font-size:100%; background:yellow; color:black;}

::selection      {background-color:yellow; color:black;}
::-moz-selection {background-color:yellow; color:black;}
</style>

</head>

<body>

<form name='form1' method='post' action="$_RUN_">

<table width='800' border='0' cellspacing='1' cellpadding='3'>

<tr><td colspan="$ColSpan" style='color:white; background-color:#000044; border:2px solid white; border-radius:8px 8px 0px 0px;'>$_INTERFACE_TITLE_</td></tr>


<tr><td><b>Enter Calendar Date and Time TT&nbsp;&nbsp;&nbsp;&nbsp;&nbsp; (Neg / Pos &nbsp;=&nbsp; BC / AD)</b>
<br><br>
<b>DATE:&nbsp; Year&nbsp; Month&nbsp; Day <input name='yn'  type='text' value="$yn"  size='7' maxlength='6'>
<input name='mn'  type='text' value="$mn"  size='3' maxlength='2'>
<input name='dn'  type='text' value="$dn"  size='3' maxlength='2'>
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Time TT
<input name='TT'  type='text' value="$TT"  size='9' maxlength='8'></b>

</td></tr>




<tr><td colspan="$ColSpan" style='background-color:black;'>
<input name='ComputeButton' type='submit' value=' C O M P U T E '>
</td></tr>



<tr>
<td colspan="$ColSpan" style='color:white; background-color:black;'>
<br>
Double-Click Within Text Area to Select ALL Text<br>
<textarea name='TextArea1' style='color:$TxColor; background:$BgColor; padding:6px; border:2px solid white;' cols="81" rows="$TextArea1Rows" ReadOnly OnDblClick='this.select();' OnMouseUp='return true;'>
$TextArea1Text
</textarea></td>
</tr>



<tr>
<td colspan="$ColSpan" style='background:black;'>
<textarea name='TextArea2' style='color:black; background:white; padding:6px;' cols="81" rows="$TextArea2Rows" ReadOnly>
$TextArea2Text
</textarea></td>
</tr>


<tr><td colspan="$ColSpan" style='color:gray; background:black;'>Program by $_AUTHOR_<br>$_REVISION_DATE_</td></tr>

$DLLink

</table>
</form>

<br><br><br><br><br><br><br><br><br><br><br><br>
<br><br><br><br><br><br><br><br><br><br><br><br>

</body>




_HTML;


?>


